pub struct PlaybackRepeatRequest {
pub mode: i32,
}Fields
mode: i32Implementations
Sourceimpl PlaybackRepeatRequest
impl PlaybackRepeatRequest
Sourcepub fn mode(&self) -> RepeatMode
pub fn mode(&self) -> RepeatMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: RepeatMode)
pub fn set_mode(&mut self, value: RepeatMode)
Sets mode to the provided enum value.
Sourceimpl PlaybackRepeatRequest
impl PlaybackRepeatRequest
pub fn new(mode: impl Into<RepeatMode>) -> Self