pub struct PlaylistBrief {
pub id: RecordId,
pub name: String,
}Fields
id: RecordIdname: StringTrait Implementations
Sourceimpl Clone for PlaylistBrief
impl Clone for PlaylistBrief
Sourcefn clone(&self) -> PlaylistBrief
fn clone(&self) -> PlaylistBrief
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlaylistBrief
impl Debug for PlaylistBrief
Sourceimpl Default for PlaylistBrief
impl Default for PlaylistBrief
Sourceimpl From<Playlist> for PlaylistBrief
impl From<Playlist> for PlaylistBrief
Sourceimpl From<Playlist> for PlaylistBrief
impl From<Playlist> for PlaylistBrief
Sourceimpl From<PlaylistBrief> for PlaylistBrief
impl From<PlaylistBrief> for PlaylistBrief
Sourcefn from(value: PlaylistBrief) -> Self
fn from(value: PlaylistBrief) -> Self
Converts to this type from the input type.
Sourceimpl Hash for PlaylistBrief
impl Hash for PlaylistBrief
Sourceimpl Message for PlaylistBrief
impl Message for PlaylistBrief
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PlaylistBrief
impl PartialEq for PlaylistBrief
impl Eq for PlaylistBrief
impl StructuralPartialEq for PlaylistBrief