pub struct StateAudio {
pub queue: Vec<SongBrief>,
pub queue_position: Option<u64>,
pub current_song: Option<SongBrief>,
pub repeat_mode: i32,
pub runtime: Option<StateRuntime>,
pub status: i32,
pub muted: bool,
pub volume: f32,
}Fields
queue: Vec<SongBrief>queue_position: Option<u64>current_song: Option<SongBrief>repeat_mode: i32runtime: Option<StateRuntime>status: i32muted: boolvolume: f32Implementations
Sourceimpl StateAudio
impl StateAudio
Sourcepub fn queue_position(&self) -> u64
pub fn queue_position(&self) -> u64
Returns the value of queue_position, or the default value if queue_position is unset.
Sourcepub fn repeat_mode(&self) -> RepeatMode
pub fn repeat_mode(&self) -> RepeatMode
Returns the enum value of repeat_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_repeat_mode(&mut self, value: RepeatMode)
pub fn set_repeat_mode(&mut self, value: RepeatMode)
Sets repeat_mode to the provided enum value.
Sourcepub fn status(&self) -> PlaybackStatus
pub fn status(&self) -> PlaybackStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: PlaybackStatus)
pub fn set_status(&mut self, value: PlaybackStatus)
Sets status to the provided enum value.