pub struct StateRuntime {
pub seek_position: Duration,
pub seek_percent: f32,
pub duration: Duration,
}Fields
seek_position: Durationseek_percent: f32duration: DurationTrait Implementations
Sourceimpl Clone for StateRuntime
impl Clone for StateRuntime
Sourcefn clone(&self) -> StateRuntime
fn clone(&self) -> StateRuntime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateRuntime
impl Debug for StateRuntime
Sourceimpl Default for StateRuntime
impl Default for StateRuntime
Sourceimpl From<StateRuntime> for StateRuntime
impl From<StateRuntime> for StateRuntime
Sourcefn from(value: StateRuntime) -> Self
fn from(value: StateRuntime) -> Self
Converts to this type from the input type.
Sourceimpl From<StateRuntime> for StateRuntime
impl From<StateRuntime> for StateRuntime
Sourcefn from(value: StateRuntime) -> Self
fn from(value: StateRuntime) -> Self
Converts to this type from the input type.
Sourceimpl Message for StateRuntime
impl Message for StateRuntime
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StateRuntime
impl PartialEq for StateRuntime
impl Copy for StateRuntime
impl StructuralPartialEq for StateRuntime