pub type LibraryHealth = LibraryHealthResponse;Aliased Type
pub struct LibraryHealth {
pub artists: u64,
pub albums: u64,
pub songs: u64,
pub unanalyzed_songs: Option<u64>,
pub playlists: u64,
pub collections: u64,
pub dynamic_playlists: u64,
pub orphaned_artists: u64,
pub orphaned_albums: u64,
pub orphaned_playlists: u64,
pub orphaned_collections: u64,
}Fields
artists: u64The number of artists in the library
albums: u64The number of albums in the library
songs: u64The number of songs in the library
unanalyzed_songs: Option<u64>The number of unanalyzed songs in the library Optional because the analysis feature may not be enabled for the daemon
playlists: u64The number of playlists in the library
collections: u64The number of collections in the library
dynamic_playlists: u64The number of dynamic playlists in the library
orphaned_artists: u64The number of orphaned songs in the library This is the number of artists that have no songs, and no albums
orphaned_albums: u64The number of orphaned albums in the library This is the number of albums that have no songs
orphaned_playlists: u64The number of orphaned playlists in the library This is the number of playlists that have no songs
orphaned_collections: u64The number of orphaned collections in the library This is the number of collections that have no songs
TODO: implement counting of missing items // The number of missing artists in the library // This is the number of artists of songs/albums that are not in the library required uint64 missing_artists = 12; // The number of missing albums in the library // This is the number of albums of songs that are not in the library required uint64 missing_albums = 13; // The number of missing songs in the library // This is the number of songs that are not in the library required uint64 missing_songs = 14; // The number of missing playlists in the library // This is the number of playlists that are not in the library required uint64 missing_playlists = 15; // The number of missing collections in the library // This is the number of collections that are not in the library required uint64 missing_collections = 16; // The number of missing files required uint64 missing_files = 17;